/*
   Copyright 2009,2010 Ricardo Cañuelo Navarro

   This file is part of Oolong.

   Oolong is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Oolong is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Oolong.  If not, see <http://www.gnu.org/licenses/>.
*/

package es.rediris.forja.tea.main;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;

/**
 * A class for creating an About box for Oolong
 * @author Ricardo Cañuelo Navarro
 *
 */
public class AboutBox
{
	/*
	 * The About box contains an icon, a label and a button
	 * all inside a panel and laid out vertically aligned (with a BoxLayout)
	 * The button launches another dialog showing the license terms.
	 * 
	 * To launch the About box, a JDialog is created and then the panel
	 * is set as its content pane
	 */
	
	/* Window widgets */
	JPanel mainPanel;
	JLabel infoLabel, logo;
	JButton okButton, licenseButton;
	ImageIcon teaLogo;
	
	/* Instance variables for reading the license file, etc */
	File licenseFile;
	FileReader fileReader;
	BufferedReader reader;
	StringBuilder licenseString;
	
	/* Other variables */
	JDialog aboutDialog;		// The About box dialog
	LicenseDialog licenseDialog;	// The license dialog
	Frame ownerFrame;		// The Frame from which the About box is called
	
	/**
	 * Creates a new About box with a specified owner, but doesn't show it
	 * @param aFrame The owner of the About box
	 */
	public AboutBox(Frame aFrame)
	{
		/* Widgets instantiation and setup */
		ownerFrame = aFrame;
		aboutDialog = new JDialog(aFrame, "Acerca de Oolong", true);
		mainPanel = new JPanel();
		teaLogo = new ImageIcon("images/tea_logo.png");
		logo = new JLabel(teaLogo);
		infoLabel = new JLabel("<html><p align='center'><b>Oolong</b></p>"+
			"<p align='center'>Copyright (C) 2009 Ricardo Cañuelo Navarro</p>" +
			"<p align='center'>This program comes with</p>" +
			"<p align='center'>ABSOLUTELY NO WARRANTY</p>" +
			"<p align='center'>This is free software, and you are welcome to</p>" +
			"<p align='center'>redistribute it under certain conditions</p></html>");
		licenseButton = new JButton("License");
		
		/* Load the license file */
		try {
			licenseFile = new File("texts/license.txt");
			fileReader = new FileReader(licenseFile);
			reader = new BufferedReader(fileReader);
		} catch(Exception ex){}
		licenseString = new StringBuilder();
		loadLicense();
		
		/* Create a LicenseDialog */
		licenseDialog = new LicenseDialog(aboutDialog, licenseString.toString());
		
		/* Set up action listeners for the widgets */
		licenseButton.addActionListener(new LicenseButtonListener());
		
		/* Set up the panel and add the widgets */
		mainPanel.setLayout(new BoxLayout(mainPanel, BoxLayout.Y_AXIS));
		mainPanel.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		logo.setAlignmentX(Component.CENTER_ALIGNMENT);
		infoLabel.setAlignmentX(Component.CENTER_ALIGNMENT);
		licenseButton.setAlignmentX(Component.CENTER_ALIGNMENT);
		infoLabel.setBorder(BorderFactory.createEmptyBorder(20, 0, 20, 0));
		mainPanel.add(logo);
		mainPanel.add(infoLabel);
		mainPanel.add(licenseButton);
		aboutDialog.setContentPane(mainPanel);
		aboutDialog.pack();
		aboutDialog.setResizable(false);
	}
	
	/**
	 * Shows the About box
	 */
	public void draw()
	{
		aboutDialog.setLocationRelativeTo(ownerFrame);
		aboutDialog.setVisible(true);
	}
	
	/**
	 * Loads the license file contents into an instance variable (licenseString)
	 */
	void loadLicense()
	{
		String line = null;
		try {
			while((line = reader.readLine()) != null) {
				licenseString.append(line);
				licenseString.append("\n");
			}
		} catch(Exception ex) {
			licenseString = new StringBuilder("No se encontró el archivo que contiene la licencia");
		}
	}
	
	/* Inner classes for implementing the action listeners */
	
	/**
	 * Implements an ActionListener for the licenseButton
	 */
	class LicenseButtonListener implements ActionListener
	{
		public void actionPerformed(ActionEvent evt)
		{
			licenseDialog.draw();
		}
	}
}

/**
 * A class for creating a dialog that shows the license terms for an application
 */
class LicenseDialog
{
	/* Widgets */
	JDialog licenseDialog;
	JPanel panel;
	JTextArea licenseTextArea;
	JScrollPane scroller;
	
	/* The dialog from which the license dialog is called */
	Dialog ownerDialog;
	
	/**
	 * Creates a new license dialog, but doesn't show it
	 * @param aDialog The owner of the license dialog
	 * @param license The string to show as the license
	 */
	public LicenseDialog(Dialog aDialog, String license)
	{
		/* Instantiate and setup the widgets */
		ownerDialog=aDialog;
		panel = new JPanel();
		licenseTextArea = new JTextArea(17,40);
		scroller = new JScrollPane(licenseTextArea);
		licenseTextArea.setLineWrap(true);
		scroller.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_AS_NEEDED);
		scroller.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
		panel.add(scroller);
		licenseTextArea.setText(license);
		licenseTextArea.setEditable(false);

		/* Create and setup the dialog */
		licenseDialog= new JDialog(aDialog, "Licencia", true);
		licenseDialog.setContentPane(panel);
		licenseDialog.pack();
		licenseDialog.setResizable(false);
	}
	
	/**
	 * Show the license dialog
	 */
	public void draw()
	{
		licenseDialog.setLocationRelativeTo(ownerDialog);
		licenseDialog.setVisible(true);	
	}	
}
