/*
   Copyright 2010 Ricardo Cañuelo Navarro

   This file is part of Oolong.

   Oolong is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Oolong is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Oolong.  If not, see <http://www.gnu.org/licenses/>.
*/

package es.rediris.forja.tea.main;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import es.rediris.forja.tea.api.*;

/**
 * A class for creating a connection dialog
 * @author Ricardo Cañuelo Navarro
 *
 */
public class Connect
{
	/*
	 * The connect dialog asks for a server name and port.
	 * It creates a plugin that retrieves data from that server
	 */

	/* Window widgets */
	JPanel mainPanel;
	JLabel serverLabel, portLabel;
	JTextField serverText, portText;
	JButton goButton;

	/* Other variables */
	JDialog connectDialog;	// The Connect dialog
	Frame ownerFrame;	// The Frame from which the About box is called
	Plugin meter;

	/**
	 * Creates a Connect dialog with a specified owner
	 * @param aFrame The owner of the Connect dialog
	 */
	public Connect(Frame aFrame)
	{
		/* Widgets instantiation and setup */
		ownerFrame = aFrame;
		connectDialog = new JDialog(aFrame, "Conectar con", false);
		mainPanel = new JPanel();
		serverLabel = new JLabel("Servidor:");
		portLabel = new JLabel("Puerto:");
		serverText = new JTextField(50);
		portText = new JTextField(6);
		goButton = new JButton("Conectar");

		/* Set up an action listener for the button */
		goButton.addActionListener(new GoButtonListener());

		/* Set up the panel and add the widgets */
		mainPanel.add(serverLabel);
		mainPanel.add(serverText);
		mainPanel.add(portLabel);
		mainPanel.add(portText);
		mainPanel.add(goButton);
		connectDialog.setContentPane(mainPanel);
		connectDialog.pack();
		connectDialog.setResizable(true);
	}

	/**
	 * Shows the dialog
	 */
	public void draw(Plugin met)
	{
		meter = met;
		connectDialog.setLocationRelativeTo(ownerFrame);
		connectDialog.setVisible(true);
	}

	/* Inner classes for implementing the action listeners */

	/**
	 * Implements an action listener for the go button
	 */
	class GoButtonListener implements ActionListener
	{
		public void actionPerformed(ActionEvent evt)
		{
			connectDialog.setVisible(false);
			meter.setServer(serverText.getText());
			meter.setPort(portText.getText());
			meter.go();
		}
	}
}
